@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "howm" "1.5.6"
+(define-package "howm" "20251005.1120"
   "Wiki-like note-taking tool."
   '((cl-lib "0.5"))
   :url "https://kaorahi.github.io/howm/"
-  :commit "7e49045c23749b61d8c93df68ad9502292fd61bc"
-  :revdesc "7e49045c2374"
+  :commit "d1431c9e678de6e0c179b2a2bf405e8804472fee"
+  :revdesc "d1431c9e678d"
   :authors '(("HIRAOKA Kazuyuki" . "kakkokakko@gmail.com"))
   :maintainers '(("HIRAOKA Kazuyuki" . "kakkokakko@gmail.com")))
